Flask-Autodoc: génération automatique de doc
============================================
![category](développement)
![tag](python)
![tag](flask)

Quand on utilise un framework web comme flask pour faire un serveur de service
par exemple il est parois utile de pouvoir générer une documentation facile
d'accès (mode web) pour les utilisateurs.

Pour cela flask possède une extension Flask-Autodoc

Installation
------------

```bash
pip install flask-autodoc
```

Utilisation
-----------

Pour une utilisation complète je vous laisse voir le documentation officielle
de l'extension sur https://github.com/acoomans/flask-autodoc

```python
from flask import Flask
from flask.ext.autodoc import Autodoc

app = Flask(__name__)
auto = Autodoc(app)

@app.route('/user/<int:id>')
@auto.doc()
def show_user(id):
    "mon aide en ligne"
    return user_from_database(id)

@app.route('/documentation')
def documentation():
    return auto.html()

if __name__ == "__main__":
    app.run()
```

et voilà le résultat

![flaskdoc.png](./upload/flaskdoc.png)

```note
il est possible de modifier le template
```

```note
il est possible de gérer une notion de groupe de documentation
```

Utilisation avancée
-------------------

Il est possible de changer la sortie html de l'autodoc et d'ajouter  des fonctions.

Il est par exemple possible de faire traiter les docstrings des fonctions par
le module docutils.

```python
from flask import Flask
from flask.ext.autodoc import Autodoc

try:
    from docutils import core
    RESTIFY=True
except:
    RESTIFY = False

app = Flask(__name__)
auto = Autodoc(app)

def rsttohtml(rst):
    if RESTIFY:
        return core.publish_parts(rst, writer_name='html')['html_body']
    return '<div class="document">%s</div>' % rst

@app.route('/user/<int:id>')
@auto.doc()
def show_user(id):
    """
        mon **aide** en ligne

        sur plusieurs lignes
    """
    return user_from_database(id)

@app.route('/documentation')
def documentation():
    return auto.html(template='myautodoc.html', rsttohtml=rsttohtml)

if __name__ == "__main__":
    app.run()
```

et il faut ajouter le fichier **myautodoc.html** dans un dossier template au niveau
du fichier python

```html
<html>
    <head>
        <title>
            {% if title is defined -%}
                {{title}}
            {% else -%}
                Documentation
            {% endif -%}
        </title>
        <style>
            * {
                margin: 0;
                padding: 0;
                font-family: Verdana, "Helvetica Neue", Arial, Helvetica, Geneva, sans-serif;
            }

            body {
                margin: 10px;
            }

            div.mapping {
                margin: 20px 20px;
            }

            ul.methods:before { content: "Methods: "; }
            ul.methods li {
                display: inline;
                list-style: none;
            }
            ul.methods li:after { content: ","; }
            ul.methods li:last-child:after { content: ""; }

            ul.arguments:before { content: "Arguments: "; }
            ul.arguments li {
                display: inline;
                list-style: none;
            }
            ul.arguments .argument { font-style:italic }
            ul.arguments .default:not(:empty):before { content: "("; }
            ul.arguments .default:not(:empty):after { content: ")"; }
            ul.arguments li:after { content: ","; }
            ul.arguments li:last-child:after { content: ""; }

            .docstring:before { content: "Description: "; }
        </style>
    </head>
    <body>
        <h1>
            {% if title is defined -%}
                {{title}}
            {% else -%}
                Documentation
            {% endif -%}
        </h1>

        {% for doc in autodoc %}
        <div class="mapping">
            <a id="rule-{{doc.rule|urlencode}}" class="rule"><h2>{{doc.rule|escape}}</h2></a>
            <ul class="methods">
                    {% for method in doc.methods -%}
                    <li class="method">{{method}}</li>
                    {% endfor %}
            </ul>
            <ul class="arguments">
                {% for arg in doc.args %}
                <li>
                    <span class="argument">{{arg}}</span>
                    <span class="default">{{doc.defaults[arg]}}</span>
                </li>
                {% endfor %}
            </ul>
            <p class="docstring">{{ rsttohtml(doc.docstring)|safe }}</p>

        </div>
        {% endfor %}
    </body>
</html>```
